@@ -5,8 +5,9 @@ class StepFunction:
     This class serves to represent and manipulate Macaulay Step MathFunctions programmatically.
     Multiplication and division only work with constants, unlike addition and subtraction.
     '''
-    def __init__(self, arr):
+    def __init__(self, arr, symbol='z'):
         self.ary = [item for item in arr if item[0] != 0] # Removes zeros
+        self.s = symbol
 
     def __add__(self, other):
         arr = self.ary + (other.ary if isinstance(other, StepFunction) else [[other, 0, 0]])
@@ -70,6 +71,6 @@ class StepFunction:
 
     min = lambda self, a, b: self(self.argmin(a, b))
 
-    __repr__ = __str__ = lambda self: ' '.join(f"{'+'*int(c>0)}{round(c, 5)}[x{'-'+str(round(r, 2)) if r else ''}]^{e}" for c,r,e in self.ary)
+    __repr__ = __str__ = lambda self: ' '.join(f"{'+'*int(c>0)}{round(c, 5)}[{self.s}{'-'+str(round(r, 2)) if r else ''}]^{e}" for c,r,e in self.ary)
 
     __rmul__, __radd__ = __mul__, __add__ # Commutative methods
